@@ -143,6 +143,8 @@ pub const LIBSSH2_SFTP_RENAME_OVERWRITE: c_long = 0x1;
 pub const LIBSSH2_SFTP_RENAME_ATOMIC: c_long = 0x2;
 pub const LIBSSH2_SFTP_RENAME_NATIVE: c_long = 0x4;
 
+pub const LIBSSH2_INIT_NO_CRYPTO: c_int = 0x1;
+
 pub enum LIBSSH2_SESSION {}
 pub enum LIBSSH2_AGENT {}
 pub enum LIBSSH2_CHANNEL {}
@@ -209,8 +211,12 @@ pub type LIBSSH2_PASSWD_CHANGEREQ_FUNC = extern fn(sess: *mut LIBSSH2_SESSION,
                                                    newpw_len: *mut c_int,
                                                    abstrakt: *mut *mut c_void);
 
-#[cfg(unix)]    pub type libssh2_socket_t = c_int;
-#[cfg(windows)] pub type libssh2_socket_t = libc::SOCKET;
+#[cfg(unix)]
+pub type libssh2_socket_t = c_int;
+#[cfg(all(windows, target_arch = "x86"))]
+pub type libssh2_socket_t = u32;
+#[cfg(all(windows, target_arch = "x86_64"))]
+pub type libssh2_socket_t = u64;
 
 extern {
     // misc
